@@ -9,7 +9,7 @@ format_root_section <- function() {
     "starting with the current working directory during package load time,",
     "the directory hierarchy is walked upwards ",
     "until a directory with at least one of the following conditions is found:",
-    gsub('"([^"]+)"', "`\\1`", format_root_criteria_items()),
+    format_root_criteria_items(),
     "",
     "In either case, `here()` appends its arguments as path components ",
     "to the root directory.",
@@ -21,6 +21,7 @@ format_root_section <- function() {
 
 format_root_criteria_items <- function(indent = 0) {
   format <- format(.root_env$root$crit)[-1L]
+  format <- gsub("'([^']+)'", "`\\1`", format)
   format <- paste0(strrep(" ", indent), format)
   paste(format, collapse = "\n")
 }
